<!doctype html>
<meta charset="utf-8">
<title>Iframe focus event after different site iframe gets focus outer</title>
<iframe src="http://{{hosts[alt][www]}}:{{ports[http][0]}}/_mozilla/focus/support/iframe-focus-event-after-iframe-gets-focus-inner.html"></iframe>
<script>
let outerlog = "outerlog:";

let iframe = document.querySelector("iframe");
window.onmessage = function(e) {
  if (e.data == "start") {
    window.onfocus = function() {
      outerlog += "windowfocus,";
    };
  } else if (e.data == "iframefocus") {
    iframe.focus();
  } else if (e.data == "iframecontentWindowfocus") {
    iframe.contentWindow.focus();
  } else if (e.data == "windowfocus") {
    iframe.contentWindow.postMessage("windowfocus", "*");
  } else if (e.data == "getlog") {
    iframe.contentWindow.postMessage("getlog", "*");
  } else {
    opener.postMessage(outerlog + e.data, "*");
  }
};

window.onload = function() {
  window.onblur = function() {
    outerlog += "windowblur,";
  };

  iframe.onfocus = function() {
    outerlog += "iframefocus,";
  };

  iframe.onblur = function() {
    outerlog += "iframeblur,";
  };

  opener.postMessage("ready", "*");
};
</script>
